
/* Generated data (by glib-mkenums) */

#ifndef __OSINFO_ENUM_TYPES_H__
#define __OSINFO_ENUM_TYPES_H__

#include <osinfo/osinfo.h>

G_BEGIN_DECLS

/* enumerations from "./osinfo_install_config_param.h" */
GType osinfo_install_config_param_policy_get_type (void) G_GNUC_CONST;
#define OSINFO_TYPE_INSTALL_CONFIG_PARAM_POLICY (osinfo_install_config_param_policy_get_type ())
GType osinfo_path_format_get_type (void) G_GNUC_CONST;
#define OSINFO_TYPE_PATH_FORMAT (osinfo_path_format_get_type ())
GType osinfo_device_driver_signing_req_get_type (void) G_GNUC_CONST;
#define OSINFO_TYPE_DEVICE_DRIVER_SIGNING_REQ (osinfo_device_driver_signing_req_get_type ())
GType osinfo_product_relationship_get_type (void) G_GNUC_CONST;
#define OSINFO_TYPE_PRODUCT_RELATIONSHIP (osinfo_product_relationship_get_type ())
GType osinfo_media_error_get_type (void) G_GNUC_CONST;
#define OSINFO_TYPE_MEDIA_ERROR (osinfo_media_error_get_type ())
G_END_DECLS

#endif /* __OSINFO_ENUM_TYPES_H__ */

/* Generated data ends here */

